@@ -7,34 +7,41 @@ TODO:
     * Handle distortion in connected polyhedra description.
 """
 
-from typing import Dict, Any, Tuple, List, Union
+from typing import Any, Dict, List, Tuple, Union
 
-from pymatgen.util.string import latexify, unicodeify, htmlify
-from pymatgen.util.string import latexify_spacegroup
-from robocrys.describe.adapter import DescriptionAdapter
-from robocrys.util import (geometry_to_polyhedra, dimensionality_to_shape,
-                           get_el, polyhedra_plurals, get_formatted_el,
-                           unicodeify_spacegroup, htmlify_spacegroup)
 import inflect
+from pymatgen.util.string import htmlify, latexify, latexify_spacegroup, unicodeify
+
+from robocrys.describe.adapter import DescriptionAdapter
+from robocrys.util import (
+    dimensionality_to_shape,
+    geometry_to_polyhedra,
+    get_el,
+    get_formatted_el,
+    htmlify_spacegroup,
+    polyhedra_plurals,
+    unicodeify_spacegroup,
+)
 
 en = inflect.engine()
 
 
-class StructureDescriber(object):
-
-    def __init__(self,
-                 describe_mineral: bool = True,
-                 describe_component_makeup: bool = True,
-                 describe_components: bool = True,
-                 describe_symmetry_labels: bool = True,
-                 describe_oxidation_states: bool = True,
-                 describe_bond_lengths: bool = True,
-                 bond_length_decimal_places: int = 2,
-                 distorted_tol: float = 0.6,
-                 only_describe_cation_polyhedra_connectivity: bool = True,
-                 only_describe_bonds_once: bool = True,
-                 fmt: str = "raw",
-                 return_parts: bool = False):
+class StructureDescriber:
+    def __init__(
+        self,
+        describe_mineral: bool = True,
+        describe_component_makeup: bool = True,
+        describe_components: bool = True,
+        describe_symmetry_labels: bool = True,
+        describe_oxidation_states: bool = True,
+        describe_bond_lengths: bool = True,
+        bond_length_decimal_places: int = 2,
+        distorted_tol: float = 0.6,
+        only_describe_cation_polyhedra_connectivity: bool = True,
+        only_describe_bonds_once: bool = True,
+        fmt: str = "raw",
+        return_parts: bool = False,
+    ):
         """A class to convert condensed structure data into text descriptions.
 
         Args:
@@ -78,8 +85,7 @@ class StructureDescriber(object):
         self.describe_oxidation_state = describe_oxidation_states
         self.describe_bond_lengths = describe_bond_lengths
         self.bond_length_decimal_places = bond_length_decimal_places
-        self.cation_polyhedra_only = \
-            only_describe_cation_polyhedra_connectivity
+        self.cation_polyhedra_only = only_describe_cation_polyhedra_connectivity
         self.only_describe_bonds_once = only_describe_bonds_once
         self.fmt = fmt
         self.return_parts = return_parts
@@ -95,8 +101,9 @@ class StructureDescriber(object):
         self._da: DescriptionAdapter = None
         self._seen_bonds: set = None
 
-    def describe(self, condensed_structure: Dict[str, Any]
-                 ) -> Union[str, Dict[str, str]]:
+    def describe(
+        self, condensed_structure: Dict[str, Any]
+    ) -> Union[str, Dict[str, str]]:
         """Convert a condensed structure into a text description.
 
         Args:
@@ -117,20 +124,20 @@ class StructureDescriber(object):
         description = {}
 
         if self.describe_mineral:
-            description['mineral'] = self.get_mineral_description()
+            description["mineral"] = self.get_mineral_description()
 
         if self.describe_component_makeup:
-            description['component_makeup'] = (
-                self.get_component_makeup_summary())
+            description["component_makeup"] = self.get_component_makeup_summary()
 
         if self.describe_components:
-            description['components'] = self.get_all_component_descriptions()
+            description["components"] = self.get_all_component_descriptions()
 
         if not self.return_parts:
             return " ".join(
-                description[part] for part in
-                ['mineral', 'component_makeup', 'components']
-                if part in description and description[part] != "")
+                description[part]
+                for part in ["mineral", "component_makeup", "components"]
+                if part in description and description[part] != ""
+            )
         else:
             return description
 
@@ -164,12 +171,13 @@ class StructureDescriber(object):
         mineral_name = get_mineral_name(self._da.mineral)
 
         if mineral_name:
-            desc = "{} is {} structured and".format(formula, mineral_name)
+            desc = f"{formula} is {mineral_name} structured and"
         else:
-            desc = "{}".format(formula)
+            desc = f"{formula}"
 
         desc += " crystallizes in the {} {} space group.".format(
-            self._da.crystal_system, spg_symbol)
+            self._da.crystal_system, spg_symbol
+        )
         return desc
 
     def get_component_makeup_summary(self) -> str:
@@ -181,20 +189,30 @@ class StructureDescriber(object):
         """
         component_groups = self._da.get_component_groups()
 
-        if (len(component_groups) == 1 and component_groups[0].count == 1 and
-                component_groups[0].dimensionality == 3):
+        if (
+            len(component_groups) == 1
+            and component_groups[0].count == 1
+            and component_groups[0].dimensionality == 3
+        ):
             desc = ""
 
         else:
             if self._da.dimensionality == 3:
                 desc = "The structure consists of "
             else:
-                desc = ("The structure is {}-dimensional and consists of "
-                        "".format(en.number_to_words(self._da.dimensionality)))
+                desc = "The structure is {}-dimensional and consists of " "".format(
+                    en.number_to_words(self._da.dimensionality)
+                )
 
             component_makeup_summaries = []
-            nframeworks = len([c for g in component_groups
-                               for c in g.components if c.dimensionality == 3])
+            nframeworks = len(
+                [
+                    c
+                    for g in component_groups
+                    for c in g.components
+                    if c.dimensionality == 3
+                ]
+            )
             for component_group in component_groups:
                 if nframeworks == 1 and component_group.dimensionality == 3:
                     s_count = "a"
@@ -211,8 +229,7 @@ class StructureDescriber(object):
                     shape = en.plural(shape, s_count)
                     formula = component_group.molecule_name
                 else:
-                    shape = en.plural(dimensionality_to_shape[dimensionality],
-                                      s_count)
+                    shape = en.plural(dimensionality_to_shape[dimensionality], s_count)
                     formula = component_group.formula
 
                 if self.fmt == "latex":
@@ -223,14 +240,16 @@ class StructureDescriber(object):
                 elif self.fmt == "html":
                     formula = htmlify(formula)
 
-                comp_desc = "{} {} {}".format(s_count, formula, shape)
+                comp_desc = f"{s_count} {formula} {shape}"
 
                 if component_group.dimensionality in [1, 2]:
-                    orientations = list(set(c.orientation for c in
-                                            component_group.components))
+                    orientations = list(
+                        {c.orientation for c in component_group.components}
+                    )
                     s_direction = en.plural("direction", len(orientations))
                     comp_desc += " oriented in the {} {}".format(
-                        en.join(orientations), s_direction)
+                        en.join(orientations), s_direction
+                    )
 
                 component_makeup_summaries.append(comp_desc)
 
@@ -241,7 +260,7 @@ class StructureDescriber(object):
                 # This works because the component summaries are sorted by
                 # dimensionality
                 desc += en.join(component_makeup_summaries[:-1])
-                desc += " inside {}.".format(component_makeup_summaries[-1])
+                desc += f" inside {component_makeup_summaries[-1]}."
             else:
                 desc += en.join(component_makeup_summaries) + "."
         return desc
@@ -255,7 +274,8 @@ class StructureDescriber(object):
         if len(self._da.components) == 1:
             return self.get_component_description(
                 self._da.get_component_groups()[0].components[0].index,
-                single_component=True)
+                single_component=True,
+            )
 
         else:
             component_groups = self._da.get_component_groups()
@@ -284,18 +304,20 @@ class StructureDescriber(object):
                         s_filler = "the" if group_count == 1 else "each"
                     else:
                         s_filler = "{} of the".format(
-                            en.number_to_words(component_count))
+                            en.number_to_words(component_count)
+                        )
                         shape = en.plural(shape)
 
-                    desc = "In {} {} {}, ".format(s_filler, formula, shape)
+                    desc = f"In {s_filler} {formula} {shape}, "
                     desc += self.get_component_description(component.index)
 
                     component_descriptions.append(desc)
 
             return " ".join(component_descriptions)
 
-    def get_component_description(self, component_index: int,
-                                  single_component: bool = False) -> str:
+    def get_component_description(
+        self, component_index: int, single_component: bool = False
+    ) -> str:
         """Gets the descriptions of all sites in a component.
 
         Args:
@@ -315,10 +337,12 @@ class StructureDescriber(object):
 
             else:
                 element = get_formatted_el(
-                    site_group.element, "",
+                    site_group.element,
+                    "",
                     use_oxi_state=self.describe_oxidation_state,
                     use_sym_label=False,
-                    fmt=self.fmt)
+                    fmt=self.fmt,
+                )
 
                 if first_group and not single_component:
                     s_there = "there"
@@ -327,13 +351,11 @@ class StructureDescriber(object):
 
                 s_count = en.number_to_words(len(site_group.sites))
 
-                desc.append("{} are {} inequivalent {} sites.".format(
-                    s_there, s_count, element))
+                desc.append(f"{s_there} are {s_count} inequivalent {element} sites.")
 
                 for i, site in enumerate(site_group.sites):
                     s_ordinal = en.number_to_words(en.ordinal(i + 1))
-                    desc.append("In the {} {} site,".format(
-                        s_ordinal, element))
+                    desc.append(f"In the {s_ordinal} {element} site,")
                     desc.append(self.get_site_description(site))
 
             first_group = False
@@ -353,31 +375,34 @@ class StructureDescriber(object):
         """
         site = self._da.sites[site_index]
 
-        if (site['poly_formula'] and
-                (self.cation_polyhedra_only or '+' in site['element'])):
+        if site["poly_formula"] and (
+            self.cation_polyhedra_only or "+" in site["element"]
+        ):
             desc = self._get_poly_site_description(site_index)
             tilt_desc = self.get_octahedral_tilt_description(site_index)
             if tilt_desc:
                 desc += ". " + tilt_desc
         else:
             element = get_formatted_el(
-                site['element'], self._da.sym_labels[site_index],
+                site["element"],
+                self._da.sym_labels[site_index],
                 use_oxi_state=self.describe_oxidation_state,
                 use_sym_label=self.describe_symmetry_labels,
-                fmt=self.fmt)
+                fmt=self.fmt,
+            )
 
-            if site['geometry']['likeness'] < self.distorted_tol:
+            if site["geometry"]["likeness"] < self.distorted_tol:
                 s_geometry = "distorted "
             else:
                 s_geometry = ""
-            s_geometry += site['geometry']['type']
+            s_geometry += site["geometry"]["type"]
 
-            desc = "{} is bonded in {} geometry to ".format(
-                element, en.a(s_geometry))
+            desc = f"{element} is bonded in {en.a(s_geometry)} geometry to "
             desc += self._get_nearest_neighbor_description(site_index)
 
         bond_length_desc = self._get_nearest_neighbor_bond_length_descriptions(
-            site_index)
+            site_index
+        )
         if bond_length_desc:
             desc += ". " + bond_length_desc
         else:
@@ -399,15 +424,18 @@ class StructureDescriber(object):
         """
         site = self._da.sites[site_index]
         nnn_details = self._da.get_next_nearest_neighbor_details(
-            site_index, group=not self.describe_symmetry_labels)
+            site_index, group=not self.describe_symmetry_labels
+        )
 
         from_element = get_formatted_el(
-            site['element'], self._da.sym_labels[site_index],
+            site["element"],
+            self._da.sym_labels[site_index],
             use_oxi_state=self.describe_oxidation_state,
             use_sym_label=self.describe_symmetry_labels,
-            fmt=self.fmt)
+            fmt=self.fmt,
+        )
 
-        from_poly_formula = site['poly_formula']
+        from_poly_formula = site["poly_formula"]
         if self.fmt == "latex":
             from_poly_formula = latexify(from_poly_formula)
         elif self.fmt == "unicode":
@@ -415,41 +443,50 @@ class StructureDescriber(object):
         elif self.fmt == "html":
             from_poly_formula = htmlify(from_poly_formula)
 
-        s_from_poly_formula = get_el(site['element']) + from_poly_formula
+        s_from_poly_formula = get_el(site["element"]) + from_poly_formula
 
-        if site['geometry']['likeness'] < self.distorted_tol:
+        if site["geometry"]["likeness"] < self.distorted_tol:
             s_distorted = "distorted "
         else:
             s_distorted = ""
-        s_polyhedra = geometry_to_polyhedra[site['geometry']['type']]
+        s_polyhedra = geometry_to_polyhedra[site["geometry"]["type"]]
         s_polyhedra = polyhedra_plurals[s_polyhedra]
 
         nn_desc = self._get_nearest_neighbor_description(site_index)
-        desc = "{} is bonded to {} to form ".format(from_element, nn_desc)
+        desc = f"{from_element} is bonded to {nn_desc} to form "
 
         # handle the case we were are connected to the same type of polyhedra
-        if (nnn_details[0].element == site['element'] and
-            len(set([(nnn_site.element, nnn_site.poly_formula) for nnn_site in
-                     nnn_details]))) == 1:
-            connectivities = list(set([nnn_site.connectivity
-                                       for nnn_site in nnn_details]))
+        if (
+            nnn_details[0].element == site["element"]
+            and len(
+                {(nnn_site.element, nnn_site.poly_formula) for nnn_site in nnn_details}
+            )
+        ) == 1:
+            connectivities = list({nnn_site.connectivity for nnn_site in nnn_details})
             s_mixture = "a mixture of " if len(connectivities) != 1 else ""
             s_connectivities = en.join(connectivities)
 
             desc += "{}{}{}-sharing {} {}".format(
-                s_mixture, s_distorted, s_connectivities, s_from_poly_formula,
-                s_polyhedra)
+                s_mixture,
+                s_distorted,
+                s_connectivities,
+                s_from_poly_formula,
+                s_polyhedra,
+            )
             return desc
 
         # otherwise loop through nnn connectivities and describe individually
-        desc += "{}{} {} that share ".format(s_distorted, s_from_poly_formula,
-                                             s_polyhedra)
+        desc += "{}{} {} that share ".format(
+            s_distorted, s_from_poly_formula, s_polyhedra
+        )
         nnn_descriptions = []
         for nnn_site in nnn_details:
             to_element = get_formatted_el(
-                nnn_site.element, nnn_site.sym_label,
+                nnn_site.element,
+                nnn_site.sym_label,
                 use_oxi_state=False,
-                use_sym_label=self.describe_symmetry_labels)
+                use_sym_label=self.describe_symmetry_labels,
+            )
 
             to_poly_formula = nnn_site.poly_formula
             if self.fmt == "latex":
@@ -468,15 +505,21 @@ class StructureDescriber(object):
                 s_equivalent = " "
 
             if nnn_site.count == 1:
-                s_an = " {}".format(en.an(nnn_site.connectivity))
+                s_an = f" {en.an(nnn_site.connectivity)}"
             else:
                 s_an = ""
                 to_shape = polyhedra_plurals[to_shape]
 
-            nnn_descriptions.append("{}{} with {}{}{} {}".format(
-                s_an, en.plural(nnn_site.connectivity, nnn_site.count),
-                en.number_to_words(nnn_site.count), s_equivalent,
-                to_poly_formula, to_shape))
+            nnn_descriptions.append(
+                "{}{} with {}{}{} {}".format(
+                    s_an,
+                    en.plural(nnn_site.connectivity, nnn_site.count),
+                    en.number_to_words(nnn_site.count),
+                    s_equivalent,
+                    to_poly_formula,
+                    to_shape,
+                )
+            )
 
         return desc + en.join(nnn_descriptions)
 
@@ -494,31 +537,36 @@ class StructureDescriber(object):
             A description of the nearest neighbors.
         """
         nn_details = self._da.get_nearest_neighbor_details(
-            site_index, group=not self.describe_symmetry_labels)
+            site_index, group=not self.describe_symmetry_labels
+        )
 
         last_count = 0
         nn_descriptions = []
         for nn_site in nn_details:
             element = get_formatted_el(
-                nn_site.element, nn_site.sym_label,
+                nn_site.element,
+                nn_site.sym_label,
                 use_oxi_state=self.describe_oxidation_state,
                 use_sym_label=self.describe_symmetry_labels,
-                fmt=self.fmt)
+                fmt=self.fmt,
+            )
 
             if len(nn_site.sites) == 1 and nn_site.count != 1:
                 s_equivalent = " equivalent "
             else:
                 s_equivalent = " "
 
-            nn_descriptions.append("{}{}{}".format(
-                en.number_to_words(nn_site.count), s_equivalent, element))
+            nn_descriptions.append(
+                "{}{}{}".format(
+                    en.number_to_words(nn_site.count), s_equivalent, element
+                )
+            )
             last_count = nn_site.count
 
         s_atoms = "atom" if last_count == 1 else "atoms"
-        return "{} {}".format(en.join(nn_descriptions), s_atoms)
+        return f"{en.join(nn_descriptions)} {s_atoms}"
 
-    def _get_nearest_neighbor_bond_length_descriptions(self, site_index: int
-                                                       ) -> str:
+    def _get_nearest_neighbor_bond_length_descriptions(self, site_index: int) -> str:
         """Gets the descriptions of the bond lengths for nearest neighbor sites.
 
         Args:
@@ -531,18 +579,19 @@ class StructureDescriber(object):
             return ""
 
         nn_details = self._da.get_nearest_neighbor_details(
-            site_index, group=not self.describe_symmetry_labels)
+            site_index, group=not self.describe_symmetry_labels
+        )
 
         bond_descriptions = []
         for nn_site in nn_details:
-            bond_descriptions.append(self.get_bond_length_description(
-                site_index, nn_site.sites))
+            bond_descriptions.append(
+                self.get_bond_length_description(site_index, nn_site.sites)
+            )
 
         # filter empty bond length description strings
         return " ".join(filter(lambda x: x, bond_descriptions))
 
-    def get_bond_length_description(self, from_site: int,
-                                    to_sites: List[int]) -> str:
+    def get_bond_length_description(self, from_site: int, to_sites: List[int]) -> str:
         """Gets a description of the bond lengths between two sets of sites.
 
         Args:
@@ -565,19 +614,22 @@ class StructureDescriber(object):
             self._da.elements[from_site],
             self._da.sym_labels[from_site],
             use_oxi_state=False,
-            use_sym_label=self.describe_symmetry_labels)
+            use_sym_label=self.describe_symmetry_labels,
+        )
         to_element = get_formatted_el(
             self._da.elements[to_sites[0]],
             self._da.get_sym_label(to_sites),
             use_oxi_state=False,
-            use_sym_label=self.describe_symmetry_labels)
+            use_sym_label=self.describe_symmetry_labels,
+        )
 
         dists = self._da.get_distance_details(from_site, to_sites)
 
         # if only one bond length
         if len(dists) == 1:
             return "The {}–{} bond length is {}.".format(
-                from_element, to_element, self._distance_to_string(dists[0]))
+                from_element, to_element, self._distance_to_string(dists[0])
+            )
 
         discrete_bond_lengths = self._rounded_bond_lengths(dists)
 
@@ -585,35 +637,46 @@ class StructureDescriber(object):
         if len(set(discrete_bond_lengths)) == 1:
             s_intro = "Both" if len(discrete_bond_lengths) == 2 else "All"
             return "{} {}–{} bond lengths are {}.".format(
-                s_intro, from_element, to_element,
-                self._distance_to_string(dists[0]))
+                s_intro, from_element, to_element, self._distance_to_string(dists[0])
+            )
 
         # if two sets of bond lengths
         if len(set(discrete_bond_lengths)) == 2:
             small = min(discrete_bond_lengths)
-            s_small_count = en.number_to_words(discrete_bond_lengths.count(
-                small))
+            s_small_count = en.number_to_words(discrete_bond_lengths.count(small))
             big = max(discrete_bond_lengths)
             s_big_count = en.number_to_words(discrete_bond_lengths.count(big))
 
-            s_length = en.plural('length', s_big_count)
+            s_length = en.plural("length", s_big_count)
 
-            return ("There {} {} shorter ({}) and {} "
-                    "longer ({}) {}–{} bond {}.").format(
-                en.plural_verb('is', s_small_count), s_small_count,
-                self._distance_to_string(small), s_big_count,
-                self._distance_to_string(big), from_element, to_element,
-                s_length)
+            return (
+                "There {} {} shorter ({}) and {} " "longer ({}) {}–{} bond {}."
+            ).format(
+                en.plural_verb("is", s_small_count),
+                s_small_count,
+                self._distance_to_string(small),
+                s_big_count,
+                self._distance_to_string(big),
+                from_element,
+                to_element,
+                s_length,
+            )
 
         # otherwise just detail the spread of bond lengths
-        return ("There are a spread of {}–{} bond distances ranging from "
-                "{}.").format(
-            from_element, to_element,
-            self._distance_range_to_string(min(discrete_bond_lengths),
-                                           max(discrete_bond_lengths)))
+        return (
+            "There are a spread of {}–{} bond distances ranging from " "{}."
+        ).format(
+            from_element,
+            to_element,
+            self._distance_range_to_string(
+                min(discrete_bond_lengths), max(discrete_bond_lengths)
+            ),
+        )
 
-    def get_octahedral_tilt_description(self, site_index: int,
-                                        ) -> str:
+    def get_octahedral_tilt_description(
+        self,
+        site_index: int,
+    ) -> str:
         """Gets a description of octahedral tilting angles between two sites.
 
         Currently only implemented for corner-sharing octahedra.
@@ -626,13 +689,16 @@ class StructureDescriber(object):
             A description of the octahedral tilting angles.
         """
         nnn_details = self._da.get_next_nearest_neighbor_details(
-            site_index, group=not self.describe_symmetry_labels)
-        to_sites = [site for nnn_site in nnn_details
-                    for site in nnn_site.sites
-                    if nnn_site.geometry == "octahedral"
-                    and nnn_site.connectivity == "corner"]
+            site_index, group=not self.describe_symmetry_labels
+        )
+        to_sites = [
+            site
+            for nnn_site in nnn_details
+            for site in nnn_site.sites
+            if nnn_site.geometry == "octahedral" and nnn_site.connectivity == "corner"
+        ]
 
-        angles = self._da.get_angle_details(site_index, to_sites, 'corner')
+        angles = self._da.get_angle_details(site_index, to_sites, "corner")
         discrete_angles = list(set(self._rounded_angles(angles)))
         tilts = [abs(180 - angle) for angle in discrete_angles]
 
@@ -645,15 +711,16 @@ class StructureDescriber(object):
                 return "The corner-sharing octahedra are not tilted"
 
             else:
-                return ("The corner-sharing octahedral tilt angles "
-                        "are {}".format(self._angle_to_string(tilts[0])))
+                return "The corner-sharing octahedral tilt angles " "are {}".format(
+                    self._angle_to_string(tilts[0])
+                )
 
         # otherwise just detail the spread of bond lengths
         return "The corner-sharing octahedral tilt angles range from {}".format(
-            self._angle_range_to_string(min(tilts), max(tilts)))
+            self._angle_range_to_string(min(tilts), max(tilts))
+        )
 
-    def _filter_seen_bonds(self, from_site: int, to_sites: List[int]
-                           ) -> List[int]:
+    def _filter_seen_bonds(self, from_site: int, to_sites: List[int]) -> List[int]:
         """Filter the list of to_sites to only include unseen bonds.
 
         Args:
@@ -680,35 +747,45 @@ class StructureDescriber(object):
 
     def _rounded_bond_lengths(self, data: List[float]) -> Tuple[float]:
         """Function to round bond lengths to a number of decimal places."""
-        return tuple(float("{:.{}f}".format(x, self.bond_length_decimal_places))
-                     for x in data)
+        return tuple(
+            float("{:.{}f}".format(x, self.bond_length_decimal_places)) for x in data
+        )
 
     def _distance_to_string(self, distance: float) -> str:
         """Utility function to round a distance and add an Angstrom symbol."""
-        return "{:.{}f} {}".format(distance, self.bond_length_decimal_places,
-                                   self.angstrom)
+        return "{:.{}f} {}".format(
+            distance, self.bond_length_decimal_places, self.angstrom
+        )
 
     def _distance_range_to_string(self, dist_a: float, dist_b: float) -> str:
         """Utility function to format a range of distances."""
         return "{:.{}f}–{:.{}f} {}".format(
-            dist_a, self.bond_length_decimal_places,
-            dist_b, self.bond_length_decimal_places, self.angstrom)
+            dist_a,
+            self.bond_length_decimal_places,
+            dist_b,
+            self.bond_length_decimal_places,
+            self.angstrom,
+        )
 
     def _rounded_angles(self, data: List[float]) -> Tuple[float]:
         """Function to round angles to a number of decimal places."""
-        return tuple(float("{:.{}f}".format(x, self.angle_decimal_places))
-                     for x in data)
+        return tuple(
+            float("{:.{}f}".format(x, self.angle_decimal_places)) for x in data
+        )
 
     def _angle_to_string(self, angle: float) -> str:
         """Utility function to round a distance and add an Angstrom symbol."""
-        return "{:.{}f}{}".format(angle, self.angle_decimal_places,
-                                  self.degree)
+        return "{:.{}f}{}".format(angle, self.angle_decimal_places, self.degree)
 
     def _angle_range_to_string(self, angle_a: float, angle_b: float) -> str:
         """Utility function to format a range of distances."""
-        return "{:.{}f}–{:.{}f}{}".format(angle_a, self.angle_decimal_places,
-                                          angle_b, self.angle_decimal_places,
-                                          self.degree)
+        return "{:.{}f}–{:.{}f}{}".format(
+            angle_a,
+            self.angle_decimal_places,
+            angle_b,
+            self.angle_decimal_places,
+            self.degree,
+        )
 
 
 def get_mineral_name(mineral_dict: Dict[str, Any]) -> Union[str, None]:
@@ -721,15 +798,15 @@ def get_mineral_name(mineral_dict: Dict[str, Any]) -> Union[str, None]:
         If ``mineral_dict["type"]`` is set, the mineral name will be returned as
         a string, else ``None`` will be returned.
     """
-    if mineral_dict['type']:
-        if not mineral_dict['n_species_type_match']:
+    if mineral_dict["type"]:
+        if not mineral_dict["n_species_type_match"]:
             suffix = "-derived"
-        elif mineral_dict['distance'] >= 0:
+        elif mineral_dict["distance"] >= 0:
             suffix = "-like"
         else:
             suffix = ""
 
-        return "{}{}".format(mineral_dict['type'], suffix)
+        return "{}{}".format(mineral_dict["type"], suffix)
 
     else:
         return None
