@@ -14,52 +14,63 @@ Attributes:
 """
 import re
 from collections import defaultdict
-from typing import Union, Dict, List, Any
+from typing import Any, Dict, List, Union
 
 from monty.json import MontyDecoder
 from monty.serialization import loadfn
 from pkg_resources import resource_filename
-
-from pymatgen import Element
-from pymatgen.core.periodic_table import get_el_sp, Species
+from pymatgen.core.periodic_table import Element, Species, get_el_sp
 from pymatgen.util.string import latexify_spacegroup
 
 common_formulas: Dict[str, str] = loadfn(
-    resource_filename('robocrys.condense', 'formula_db.json.gz'))
+    resource_filename("robocrys.condense", "formula_db.json.gz")
+)
 
 connected_geometries: List[str] = [
-    'tetrahedral', 'octahedral', 'trigonal pyramidal',
-    'square pyramidal', 'trigonal bipyramidal',
-    'pentagonal pyramidal', 'hexagonal pyramidal',
-    'pentagonal bipyramidal', 'hexagonal bipyramidal',
-    'cuboctahedral']
+    "tetrahedral",
+    "octahedral",
+    "trigonal pyramidal",
+    "square pyramidal",
+    "trigonal bipyramidal",
+    "pentagonal pyramidal",
+    "hexagonal pyramidal",
+    "pentagonal bipyramidal",
+    "hexagonal bipyramidal",
+    "cuboctahedral",
+]
 
 geometry_to_polyhedra: Dict[str, str] = {
-    'octahedral': 'octahedra',
-    'tetrahedral': 'tetrahedra',
-    'trigonal pyramidal': 'trigonal pyramid',
-    'square pyramidal': 'square pyramid',
-    'trigonal bipyramidal': 'trigonal bipyramid',
-    'pentagonal pyramidal': 'pentagonal pyramid',
-    'hexagonal pyramidal': 'hexagonal pyramid',
-    'pentagonal bipyramidal': 'pentagonal bipyramid',
-    'hexagonal bipyramidal': 'hexagonal bipyramid',
-    'cuboctahedral': 'cuboctahedra'}
+    "octahedral": "octahedra",
+    "tetrahedral": "tetrahedra",
+    "trigonal pyramidal": "trigonal pyramid",
+    "square pyramidal": "square pyramid",
+    "trigonal bipyramidal": "trigonal bipyramid",
+    "pentagonal pyramidal": "pentagonal pyramid",
+    "hexagonal pyramidal": "hexagonal pyramid",
+    "pentagonal bipyramidal": "pentagonal bipyramid",
+    "hexagonal bipyramidal": "hexagonal bipyramid",
+    "cuboctahedral": "cuboctahedra",
+}
 
 polyhedra_plurals: Dict[str, str] = {
-    'octahedra': 'octahedra',
-    'tetrahedra': 'tetrahedra',
-    'trigonal pyramid': 'trigonal pyramids',
-    'square pyramid': 'square pyramids',
-    'trigonal bipyramid': 'trigonal bipyramids',
-    'pentagonal pyramid': 'pentagonal pyramids',
-    'hexagonal pyramid': 'hexagonal pyramids',
-    'pentagonal bipyramid': 'pentagonal bipyramids',
-    'hexagonal bipyramid': 'hexagonal bipyramids',
-    'cuboctahedra': 'cuboctahedra'}
+    "octahedra": "octahedra",
+    "tetrahedra": "tetrahedra",
+    "trigonal pyramid": "trigonal pyramids",
+    "square pyramid": "square pyramids",
+    "trigonal bipyramid": "trigonal bipyramids",
+    "pentagonal pyramid": "pentagonal pyramids",
+    "hexagonal pyramid": "hexagonal pyramids",
+    "pentagonal bipyramid": "pentagonal bipyramids",
+    "hexagonal bipyramid": "hexagonal bipyramids",
+    "cuboctahedra": "cuboctahedra",
+}
 
 dimensionality_to_shape: Dict[int, str] = {
-    3: 'framework', 2: 'sheet', 1: 'ribbon', 0: 'cluster'}
+    3: "framework",
+    2: "sheet",
+    1: "ribbon",
+    0: "cluster",
+}
 
 
 def get_el(obj: Union[Element, Species, str, int]) -> str:
@@ -83,14 +94,16 @@ def get_el(obj: Union[Element, Species, str, int]) -> str:
     elif isinstance(obj, int):
         return Element.from_Z(obj).name
     else:
-        raise ValueError("Unsupported element type: {}.".format(type(obj)))
+        raise ValueError(f"Unsupported element type: {type(obj)}.")
 
 
-def get_formatted_el(element: str,
-                     sym_label: str,
-                     use_oxi_state: bool = True,
-                     use_sym_label: bool = True,
-                     fmt: str = "raw"):
+def get_formatted_el(
+    element: str,
+    sym_label: str,
+    use_oxi_state: bool = True,
+    use_sym_label: bool = True,
+    fmt: str = "raw",
+):
     """Formats an element string.
 
     Performs a variety of functions, including:
@@ -124,13 +137,13 @@ def get_formatted_el(element: str,
 
     if isinstance(specie, Species):
         oxi_state = specie.oxi_state
-        sign = '+' if oxi_state > 0 else '-'
+        sign = "+" if oxi_state > 0 else "-"
         if oxi_state == 0:
             oxi_state = None
         elif oxi_state % 1 == 0:
-            oxi_state = '{:d}{}'.format(int(abs(oxi_state)), sign)
+            oxi_state = f"{int(abs(oxi_state)):d}{sign}"
         else:
-            oxi_state = '{:+.2f}{}'.format(abs(oxi_state), sign)
+            oxi_state = f"{abs(oxi_state):+.2f}{sign}"
     else:
         oxi_state = None
 
@@ -141,13 +154,13 @@ def get_formatted_el(element: str,
 
     if use_oxi_state and oxi_state:
         if fmt == "latex":
-            oxi_state = "^{{{}}}".format(oxi_state)
+            oxi_state = f"^{{{oxi_state}}}"
 
         elif fmt == "unicode":
             oxi_state = superscript_number(oxi_state)
 
         elif fmt == "html":
-            oxi_state = "<sup>{}</sup>".format(oxi_state)
+            oxi_state = f"<sup>{oxi_state}</sup>"
 
         formatted_element += oxi_state
 
@@ -166,12 +179,24 @@ def superscript_number(string):
         The superscript string.
     """
 
-    if '.' in string:
+    if "." in string:
         # no unicode period exists
         return string
 
-    subscript_unicode_map = {0: '⁰', 1: '¹', 2: '²', 3: '³', 4: '⁴', 5: '⁵',
-                             6: '⁶', 7: '⁷', 8: '⁸', 9: '⁹', "-": "⁻", "+": "⁺"}
+    subscript_unicode_map = {
+        0: "⁰",
+        1: "¹",
+        2: "²",
+        3: "³",
+        4: "⁴",
+        5: "⁵",
+        6: "⁶",
+        7: "⁷",
+        8: "⁸",
+        9: "⁹",
+        "-": "⁻",
+        "+": "⁺",
+    }
 
     for original_subscript, subscript_unicode in subscript_unicode_map.items():
         string = string.replace(str(original_subscript), subscript_unicode)
@@ -190,8 +215,18 @@ def unicodeify_spacegroup(spacegroup_symbol: str) -> str:
     Returns:
         The unicode formatted spacegroup symbol.
     """
-    subscript_unicode_map = {0: "₀", 1: "₁", 2: "₂", 3: "₃", 4: "₄", 5: "₅",
-                             6: "₆", 7: "₇", 8: "₈", 9: "₉"}
+    subscript_unicode_map = {
+        0: "₀",
+        1: "₁",
+        2: "₂",
+        3: "₃",
+        4: "₄",
+        5: "₅",
+        6: "₆",
+        7: "₇",
+        8: "₈",
+        9: "₉",
+    }
 
     symbol = latexify_spacegroup(spacegroup_symbol)
 
@@ -221,7 +256,7 @@ def htmlify_spacegroup(spacegroup_symbol: str) -> str:
     """
     overline = "\u0305"  # u"\u0304" (macron) is also an option
     symbol = re.sub(r"_(\d+)", r"<sub>\1</sub>", spacegroup_symbol)
-    symbol = re.sub(r"-(\d)", r"{}\1".format(overline), symbol)
+    symbol = re.sub(r"-(\d)", fr"{overline}\1", symbol)
     return symbol
 
 
